==> is_opencensus-0.1.5.tar.gz: is_opencensus-0.1.5/opencensus/stats/view_manager.py <==
# Copyright 2018, OpenCensus Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from opencensus.stats.measure_to_view_map import MeasureToViewMap
from datetime import datetime


class ViewManager(object):
    """View Manager allows the registering of Views for collecting stats
    and receiving stats data as View Data"""
    def __init__(self):
        self.time = datetime.utcnow().isoformat() + 'Z'
        self._measure_view_map = MeasureToViewMap()

    @property
    def measure_to_view_map(self):
        """the current measure to view map for the View Manager"""
        return self._measure_view_map

    def register_view(self, view):
        """registers the given view"""
        self.measure_to_view_map.register_view(view=view, timestamp=self.time)

    def get_view(self, view_name):
        """gets the view given the view name """
        return self.measure_to_view_map.get_view(view_name=view_name,
                                                 timestamp=self.time)

    def get_all_exported_views(self):
        """returns all of the exported views for the current measure to view
        map"""
        return self.measure_to_view_map.exported_views

==> is_opencensus-0.1.5.1.tar.gz: is_opencensus-0.1.5.1/opencensus/stats/view_manager.py <==
# Copyright 2018, OpenCensus Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from opencensus.stats.measure_to_view_map import MeasureToViewMap
from opencensus.stats import execution_context
from datetime import datetime


class ViewManager(object):
    """View Manager allows the registering of Views for collecting stats
    and receiving stats data as View Data"""
    def __init__(self):
        self.time = datetime.utcnow().isoformat() + 'Z'
        if execution_context.get_measure_to_view_map() == {}:
            execution_context.set_measure_to_view_map(MeasureToViewMap())

        self._measure_view_map = execution_context.get_measure_to_view_map()

    @property
    def measure_to_view_map(self):
        """the current measure to view map for the View Manager"""
        return self._measure_view_map

    def register_view(self, view):
        """registers the given view"""
        self.measure_to_view_map.register_view(view=view, timestamp=self.time)

    def get_view(self, view_name):
        """gets the view given the view name """
        return self.measure_to_view_map.get_view(view_name=view_name,
                                                 timestamp=self.time)

    def get_all_exported_views(self):
        """returns all of the exported views for the current measure to view
        map"""
        return self.measure_to_view_map.exported_views
